# agi-med-utils

Стандартизация компонент общей библиотеки отдела

## Ответственный разработчик

@kopanichuk

## Общая информация

- Доступ к Yandex_GPT, Gigachat
- Стандартный конфиг
- Общие для сервисов ЦА функции
- Даталоадер для ЦА

## Тесты

- `sudo docker compose -f docker-compose.yaml up --build`
